Crate rusty_cotp

Crate rusty_cotp 

Structs

CotpConnectionParameters
Provides a set of parameters used to tune timers or prevent the runaway consumption or resources due to a malicious client.
CotpProtocolInformation
Captures information about a COTP connection allowing it to be used later for connection negotiation.
RustyCotpAcceptor
Creates a responder that consumes the underlying TPKT service to negotiate a COTP connection.
RustyCotpConnection
A COTP connection provides a packet based data exchange mechanism.
RustyCotpReader
RustyCotpWriter

Enums

CotpError

Traits

CotpConnection
A trait representing a COTP connection.
CotpReader
CotpResponder
Provides a mechnism to respond with negotiated values suring the connect phase.
CotpWriter