pub enum CotpError {
ProtocolError(String),
ProtocolStackError(TpktError),
IoError(Error),
InternalError(String),
}Variants
ProtocolError(String)
Indicates issues with parsing of incoming packets or protocol violations with input user data.
ProtocolStackError(TpktError)
Indicates issues with lower layers.
IoError(Error)
Indicates issues with the underlying TCP socket or hardware.
InternalError(String)
Usually indicates a bug or an unhandled error condition.