pub struct CotpConnectionParameters {
pub max_reassembled_payload_size: usize,
}Expand description
Provides a set of parameters used to tune timers or prevent the runaway consumption or resources due to a malicious client.
Fields
max_reassembled_payload_size: usizeA limit on the reassembled payload. If this is exceeded, an error will be raised on the read operation.
Defaults to 1MB for payload plus a 1024 byte overhead to account for headers. Only applies to inbound data.