RustyCotpResponder

Struct RustyCotpResponder 

pub struct RustyCotpResponder<R: TpktReader, W: TpktWriter> { /* private fields */ }
Creates a responder that consumes the underlying TPKT service to negotiate a COTP connection.

Implementations

Source

impl<R: TpktReader, W: TpktWriter> RustyCotpResponder<R, W>

pub async fn new( tpkt_connection: impl TpktConnection, connection_options: CotpConnectionParameters, ) -> Result<(RustyCotpResponder<impl TpktReader, impl TpktWriter>, CotpProtocolInformation), CotpError>

Creates an acceptor.

This is a single use component used to upgrade an underlying TPKT connection to a COTP connection. The TPKT connection should be a server, but this is not enforced.