CotpConnection

Trait CotpConnection 

pub trait CotpConnection: Send {
    // Required methods
    fn get_protocol_infomation_list(&self) -> &Vec<Box<dyn ProtocolInformation>>;
    fn split(
        self,
    ) -> impl Future<Output = Result<(impl CotpReader, impl CotpWriter), CotpError>> + Send;
}
A trait representing a COTP connection.

Required Methods

fn get_protocol_infomation_list(&self) -> &Vec<Box<dyn ProtocolInformation>>

Gets the information regarding the protocols that have been negotiated during the connect phase.

fn split( self, ) -> impl Future<Output = Result<(impl CotpReader, impl CotpWriter), CotpError>> + Send

Splits a connection into reader and writer components. This must be done before the connection is used.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors