Crate rusty_cotp

Crate rusty_cotp 

Structs

CotpProtocolInformation
Captures information about a COTP connection allowing it to be used later for connection negotiation.
TcpCotpAcceptor
TcpCotpConnection
TcpCotpReader
TcpCotpWriter

Enums

CotpError

Traits

CotpConnection
A trait representing a COTP connection.
CotpReader
CotpResponder
Provides a mechnism to respond with negotiated values suring the connect phase.
CotpWriter