pub struct CotpProtocolInformation { /* private fields */ }Expand description
Captures information about a COTP connection allowing it to be used later for connection negotiation.
Implementations
Sourceimpl CotpProtocolInformation
impl CotpProtocolInformation
Sourcepub fn initiator(
calling_tsap_id: Option<Vec<u8>>,
called_tsap_id: Option<Vec<u8>>,
) -> Self
pub fn initiator( calling_tsap_id: Option<Vec<u8>>, called_tsap_id: Option<Vec<u8>>, ) -> Self
Used to specify information used by the COTP service during the initiator phase. This generates a random initiator and set the responder reference to 0.
Sourcepub fn responder(self) -> Self
pub fn responder(self) -> Self
Convert initiator information received by a connection request to responder information. This generates a random responder reference.
Sourcepub fn initiator_reference(&self) -> u16
pub fn initiator_reference(&self) -> u16
The initiator reference. As this supports Class 0 only, the reference is informational.
Sourcepub fn responder_reference(&self) -> u16
pub fn responder_reference(&self) -> u16
The responder reference. As this supports Class 0 only, the reference is informational.
This will be 0 for information received from the initiator.
Sourcepub fn calling_tsap_id(&self) -> Option<&Vec<u8>>
pub fn calling_tsap_id(&self) -> Option<&Vec<u8>>
The Transport Id of the caller. Similar to a TCP port except it is not ephemeral for the calling party.
Sourcepub fn called_tsap_id(&self) -> Option<&Vec<u8>>
pub fn called_tsap_id(&self) -> Option<&Vec<u8>>
The Transport Id of the called host. Similar to a TCP port.