pub struct RustyCotpConnection<R: TpktReader, W: TpktWriter> { /* private fields */ }Expand description
A COTP connection provides a packet based data exchange mechanism.
Initiator connections may be initiated via this struct. To act as a responder, the acceptor class should be used.
Implementations
Sourceimpl<R: TpktReader, W: TpktWriter> RustyCotpConnection<R, W>
impl<R: TpktReader, W: TpktWriter> RustyCotpConnection<R, W>
Sourcepub async fn initiate(
connection: impl TpktConnection,
options: CotpProtocolInformation,
connection_options: CotpConnectionParameters,
) -> Result<RustyCotpConnection<impl TpktReader, impl TpktWriter>, CotpError>
pub async fn initiate( connection: impl TpktConnection, options: CotpProtocolInformation, connection_options: CotpConnectionParameters, ) -> Result<RustyCotpConnection<impl TpktReader, impl TpktWriter>, CotpError>
Initiates a connection to a responder COTP service.